@@ -1,4 +1,4 @@
-def main():
+if name =='__main__':
     print('main fn')
     from .code import main as ma
     ma()
